model_orbit

Function model_orbit 

pub fn model_orbit(model: &[bool], generators: &[Perm]) -> Vec<Vec<bool>>
Symmetry generates solutions. From one model, the entire orbit under a generating set of automorphisms — every member a model too, produced with no search. The generative dual of resolution (which begets rules from symmetry); here symmetry begets solutions.