pub struct InductionArg {
pub name: String,
pub recursive: bool,
}Expand description
One argument of a constructor in an InductionCase.
Fields
name: StringThe name bound for this argument in the case body.
recursive: boolWhether this argument is itself of the inductive type — a recursive position, which therefore carries an induction hypothesis.